import { SpinnerOptions, StopAllStatus } from "spinnies";
export declare class Spinner {
    name: string;
    constructor(name: string, options: Partial<SpinnerOptions>);
    constructor(name: string, text: string);
    /**
     * Stops all spinners
     * @param status the terminal state of the spinners that have been stopped (one of "stopped", "succeed", or "fail").
     */
    static stopAll(status?: StopAllStatus): void;
    /**
     * @returns false if all spinners have succeeded, failed or have been stopped
     */
    static hasActiveSpinners(): boolean;
    /**
     * Removes this spinner from display. After this method is called, other modifications to this spinner object have no effect.
     */
    remove(): void;
    /**
     * Stops the spinner without a failed or succeeded status
     */
    stop(options?: Partial<SpinnerOptions>): void;
    /**
     * Stops the spinner and sets its status to succeeded.
     */
    succeed(text?: string): void;
    /**
     * Stops the spinner and sets its status to fail.
     */
    fail(text?: string): void;
    /**
     * @returns string the spinner prefix used on success
     */
    static get succeedPrefix(): string;
    /**
     * Updates the spinner success decoration. Updates apply to all spinning
     * spinners, and do not apply to spinners that have already stopped.
     */
    static set succeedPrefix(value: string);
    /**
     * @returns string the spinner prefix used on failure
     */
    static get failPrefix(): string;
    /**
     * Updates the spinner fail decoration. Updates apply to all spinning
     * spinners, and do not apply to spinners that have already stopped.
     */
    static set failPrefix(value: string);
    /**
     * @returns string the text currently displayed by this spinner, without the
     * spinner decoration
     */
    get text(): string | undefined;
    /**
     * Updates the text displayed by this spinner
     */
    set text(value: string | undefined);
    /**
     * @returns string the `chalk` color of this spinner's text
     */
    get color(): string | undefined;
    /**
     * updates the `chalk` color of this spinner's text
     */
    set color(value: string | undefined);
    /**
     * @returns string the `chalk` color of this spinner decoration
     */
    get spinnerColor(): string | undefined;
    /**
     * updates the `chalk` color of this spinner's decoration
     */
    set spinnerColor(value: string | undefined);
    /**
     * @returns string the `chalk` color of this spinner text on success (note: on
     * success, the spinner decoration is always green)
     */
    get succeedColor(): string | undefined;
    /**
     * Updates the `chalk` color of this spinner's text on success
     */
    set succeedColor(value: string | undefined);
    /**
     * @returns string the `chalk` color of this spinner text on failure (note: on
     * failure, the spinner decoration is always red)
     */
    get failColor(): string | undefined;
    /**
     * Updates the `chalk` color of this spinner's text on failure
     */
    set failColor(value: string | undefined);
    /**
     * @returns boolean `true` when the spinner is active and spinning, otherwise
     * `false`
     */
    get isSpinning(): boolean;
    private _mutateOptions;
}
